KERN_RETURN

Enum KERN_RETURN 

pub enum KERN_RETURN {
Show 53 variants KERN_SUCCESS = 137_681_831, KERN_INVALID_ADDRESS = 137681832, KERN_PROTECTION_FAILURE = 137681833, KERN_NO_SPACE = 137681834, KERN_INVALID_ARGUMENT = 137681835, KERN_FAILURE = 137681836, KERN_RESOURCE_SHORTAGE = 137681837, KERN_NOT_RECEIVER = 137681838, KERN_NO_ACCESS = 137681839, KERN_MEMORY_FAILURE = 137681840, KERN_MEMORY_ERROR = 137681841, KERN_ALREADY_IN_SET = 137681842, KERN_NOT_IN_SET = 137681843, KERN_NAME_EXISTS = 137681844, KERN_ABORTED = 137681845, KERN_INVALID_NAME = 137681846, KERN_INVALID_TASK = 137681847, KERN_INVALID_RIGHT = 137681848, KERN_INVALID_VALUE = 137681849, KERN_UREFS_OVERFLOW = 137681850, KERN_INVALID_CAPABILITY = 137681851, KERN_RIGHT_EXISTS = 137681852, KERN_INVALID_HOST = 137681853, KERN_MEMORY_PRESENT = 137681854, KERN_MEMORY_DATA_MOVED = 137681855, KERN_MEMORY_RESTART_COPY = 137681856, KERN_INVALID_PROCESSOR_SET = 137681857, KERN_POLICY_LIMIT = 137681858, KERN_INVALID_POLICY = 137681859, KERN_INVALID_OBJECT = 137681860, KERN_ALREADY_WAITING = 137681861, KERN_DEFAULT_SET = 137681862, KERN_EXCEPTION_PROTECTED = 137681863, KERN_INVALID_LEDGER = 137681864, KERN_INVALID_MEMORY_CONTROL = 137681865, KERN_INVALID_SECURITY = 137681866, KERN_NOT_DEPRESSED = 137681867, KERN_TERMINATED = 137681868, KERN_LOCK_SET_DESTROYED = 137681869, KERN_LOCK_UNSTABLE = 137681870, KERN_LOCK_OWNED = 137681871, KERN_LOCK_OWNED_SELF = 137681872, KERN_SEMAPHORE_DESTROYED = 137681873, KERN_RPC_SERVER_TERMINATED = 137681874, KERN_RPC_TERMINATE_ORPHAN = 137681875, KERN_RPC_CONTINUE_ORPHAN = 137681876, KERN_NOT_SUPPORTED = 137681877, KERN_NODE_DOWN = 137681878, KERN_NOT_WAITING = 137681879, KERN_OPERATION_TIMED_OUT = 137681880, KERN_CODESIGN_ERROR = 137681881, KERN_POLICY_STATIC = 137681882, KERN_RETURN_MAX = 137681883,
}
the enum for all error code returned from mach kernel. this allows double-ended query: converting from integer to enum, and reverse mapping from enum to integer.

NOTE: the inner enum value (isize) is randomly generated by each compile. it is NOT ACTUAL kernel return code. it must not to be used from down-stream projects. this internal value just used for PartialOrd & Ord for compare between two enum instances.

Variants



KERN_SUCCESS = 137_681_831



KERN_INVALID_ADDRESS = 137681832



KERN_PROTECTION_FAILURE = 137681833



KERN_NO_SPACE = 137681834



KERN_INVALID_ARGUMENT = 137681835



KERN_FAILURE = 137681836



KERN_RESOURCE_SHORTAGE = 137681837



KERN_NOT_RECEIVER = 137681838



KERN_NO_ACCESS = 137681839



KERN_MEMORY_FAILURE = 137681840



KERN_MEMORY_ERROR = 137681841



KERN_ALREADY_IN_SET = 137681842



KERN_NOT_IN_SET = 137681843



KERN_NAME_EXISTS = 137681844



KERN_ABORTED = 137681845



KERN_INVALID_NAME = 137681846



KERN_INVALID_TASK = 137681847



KERN_INVALID_RIGHT = 137681848



KERN_INVALID_VALUE = 137681849



KERN_UREFS_OVERFLOW = 137681850



KERN_INVALID_CAPABILITY = 137681851



KERN_RIGHT_EXISTS = 137681852



KERN_INVALID_HOST = 137681853



KERN_MEMORY_PRESENT = 137681854



KERN_MEMORY_DATA_MOVED = 137681855



KERN_MEMORY_RESTART_COPY = 137681856



KERN_INVALID_PROCESSOR_SET = 137681857



KERN_POLICY_LIMIT = 137681858



KERN_INVALID_POLICY = 137681859



KERN_INVALID_OBJECT = 137681860



KERN_ALREADY_WAITING = 137681861



KERN_DEFAULT_SET = 137681862



KERN_EXCEPTION_PROTECTED = 137681863



KERN_INVALID_LEDGER = 137681864



KERN_INVALID_MEMORY_CONTROL = 137681865



KERN_INVALID_SECURITY = 137681866



KERN_NOT_DEPRESSED = 137681867



KERN_TERMINATED = 137681868



KERN_LOCK_SET_DESTROYED = 137681869



KERN_LOCK_UNSTABLE = 137681870



KERN_LOCK_OWNED = 137681871



KERN_LOCK_OWNED_SELF = 137681872



KERN_SEMAPHORE_DESTROYED = 137681873



KERN_RPC_SERVER_TERMINATED = 137681874



KERN_RPC_TERMINATE_ORPHAN = 137681875



KERN_RPC_CONTINUE_ORPHAN = 137681876



KERN_NOT_SUPPORTED = 137681877



KERN_NODE_DOWN = 137681878



KERN_NOT_WAITING = 137681879



KERN_OPERATION_TIMED_OUT = 137681880



KERN_CODESIGN_ERROR = 137681881



KERN_POLICY_STATIC = 137681882



KERN_RETURN_MAX = 137681883

Implementations

Source

impl KERN_RETURN

pub const fn stringify(&self) -> &'static str

pub const fn is_ok(&self) -> bool

pub const fn is_err(&self) -> bool

pub const fn is_success(&self) -> bool

pub const fn is_failed(&self) -> bool

pub const fn to_int(&self) -> kern_return_t

pub const fn from_int(val: kern_return_t) -> Self

pub const fn try_from_int(val: kern_return_t) -> Result<Self, kern_return_t>