pub unsafe fn mach_task_self() -> mach_port_tExpand description
SAFETY? not sure but you can use a thread lock externally, or use sync::mach_task_self.
pub unsafe fn mach_task_self() -> mach_port_tSAFETY? not sure but you can use a thread lock externally, or use sync::mach_task_self.